@@ -57,6 +57,16 @@ class Horde_Date_DateTest extends PHPUnit_Framework_TestCase
         $dt->setTimezone(new DateTimeZone('UTC'));
         $date = new Horde_Date($dt);
         $this->assertEquals('2011-12-10 03:05:06', (string)$date);
+
+        // Test creating Horde_Date from a string that will use DateTime
+        // internally to parse the date.
+        $date = new Horde_Date('2014-03-20 5:00PM');
+        $this->assertEquals('2014-03-20 17:00:00', (string)$date);
+        $this->assertEquals('Europe/Berlin', $date->timezone);
+
+        $date = new Horde_Date('2014-03-20 5:00PM', 'America/New_York');
+        $this->assertEquals('2014-03-20 17:00:00', (string)$date);
+        $this->assertEquals('America/New_York', $date->timezone);
     }
 
     /**
@@ -142,6 +152,31 @@ class Horde_Date_DateTest extends PHPUnit_Framework_TestCase
         $this->assertEquals(28, $d->day);
     }
 
+    public function testSettingDatePropertiesFromEmptyDateObject()
+    {
+        $d = new Horde_Date();
+        $d->year = 2013;
+        $d->month = 12;
+        $d->mday = 20;
+        $this->assertEquals(12, $d->month);
+        $this->assertEquals(20, $d->mday);
+
+        $d = new Horde_Date();
+        $d->year = 2013;
+        $d->mday = 1;
+        $d->month = 12;
+        $this->assertEquals(12, $d->month);
+        $this->assertEquals(1, $d->mday);
+
+        $d = new Horde_Date();
+        $d->mday = 1;
+        $d->month = 12;
+        $d->year = 2013;
+        $this->assertEquals(12, $d->month);
+        $this->assertEquals(1, $d->mday);
+        $this->assertEquals(2013, $d->year);
+    }
+
     public function testTimestamp()
     {
         $oldTimezone = date_default_timezone_get();
@@ -303,4 +338,14 @@ class Horde_Date_DateTest extends PHPUnit_Framework_TestCase
         $this->assertEquals('20100101T130000', $test->toiCalendar(true));
         $this->assertEquals('20100101T160000Z', $test->toiCalendar(false));
     }
+
+    public function testBug12843()
+    {
+        $date = new Horde_Date(1384880400, 'Europe/Berlin');
+        $this->assertEquals(18, $date->hour);
+
+        date_default_timezone_set('America/New_York');
+        $date = new Horde_Date(1384880400, 'Europe/Berlin');
+        $this->assertEquals(18, $date->hour);
+    }
 }
